@@ -75,6 +75,7 @@ help_msg = {
     "copy": "Copy assembly files to the output folder",
     "min_genome_size": "Minimum genome size where to apply heuristics to find ANI fragment size",
     "ani_fraglen_fraction": "Fraction of the genome size used to estimate the ANI used fragment length",
+    "assm_max": "Maximum number of assemblies to process for small batches",
 }
 
 
@@ -156,6 +157,14 @@ def get_arguments(argv=None):
         help=help_msg["mash_threshold"],
         dest="mash_threshold",
     )
+    optional.add_argument(
+        "--max-assemblies",
+        type=int,
+        metavar="INT",
+        dest="assm_max",
+        default=10,
+        help=help_msg["assm_max"],
+    )
     slurm.add_argument(
         "--slurm-config",
         dest="slurm_config",
@@ -394,4 +403,4 @@ def applyParallel(dfGrouped, func, threads, parms):
         p.map(func, [group for name, group in dfGrouped]),
         total=len([group for name, group in dfGrouped]),
     )
-    return pd.concat(ret_list)
\ No newline at end of file
+    return pd.concat(ret_list)
